@@ -64,7 +64,6 @@
 #define HAVE_SYS_FILE_H 1
 /* #undef HAVE_SYS_FPU_H */
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_IPC_H 1
 /* #undef HAVE_SYS_MALLOC_H */
 #define HAVE_SYS_MMAN_H 1
 /* #undef HAVE_SYS_NDIR_H */
@@ -73,7 +72,6 @@
 #define HAVE_SYS_PRCTL_H 1
 #define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
-#define HAVE_SYS_SHM_H 1
 #define HAVE_SYS_SOCKET_H 1
 /* #undef HAVE_SYS_SOCKIO_H */
 #define HAVE_SYS_UTSNAME_H 1
@@ -106,6 +104,11 @@
 #define HAVE_SYSTEMD 1
 /* #undef HAVE_CRC32_VPMSUM */
 
+/* Support ARMv8 crc + crypto  */
+#define HAVE_ARMV8_CRC 1
+#define HAVE_ARMV8_CRYPTO 1
+#define HAVE_ARMV8_CRC_CRYPTO_INTRINSICS 1
+
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
@@ -122,7 +125,6 @@
 /* Functions we may want to use. */
 #define HAVE_ACCEPT4 1
 #define HAVE_ACCESS 1
-/* #undef HAVE_AIOWAIT */
 #define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
 /* #undef HAVE_BFILL */
@@ -148,6 +150,7 @@
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
 #define HAVE_GETPAGESIZE 1
+/* #undef HAVE_GETPAGESIZES */
 #define HAVE_GETPASS 1
 /* #undef HAVE_GETPASSPHRASE */
 #define HAVE_GETPWNAM 1
@@ -160,14 +163,12 @@
 /* #undef gmtime_r */
 #define HAVE_IN_ADDR_T 1
 #define HAVE_INITGROUPS 1
-#define HAVE_LARGE_PAGE_OPTION 1
 #define HAVE_LDIV 1
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
 #define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
-#define HAVE_NPTL 1
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
 #define HAVE_DECL_MADVISE 1
@@ -382,9 +383,6 @@
 
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
-#define HAVE_DECL_SHM_HUGETLB 1
-#define HAVE_LINUX_LARGE_PAGES 1
-#define HUGETLB_USE_PROC_MEMINFO 1
 /* #undef NO_FCNTL_NONBLOCK */
 #define NO_ALARM 1
 
@@ -494,8 +492,7 @@
 #define HAVE_CHARSET_ucs2 1
 #define HAVE_CHARSET_ujis 1
 #define HAVE_CHARSET_utf8mb4 1
-/* #undef HAVE_CHARSET_utf8mb3 */
-#define HAVE_CHARSET_utf8 1
+#define HAVE_CHARSET_utf8mb3 1
 #define HAVE_CHARSET_utf16 1
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
@@ -533,18 +530,19 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 14
+#define MYSQL_VERSION_MINOR 5
+#define MYSQL_VERSION_PATCH 5
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.4.14"
+#define PACKAGE_STRING "MySQL Server 10.5.5"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.4.14"
-#define VERSION "10.4.14"
+#define PACKAGE_VERSION "10.5.5"
+#define VERSION "10.5.5"
 #define PROTOCOL_VERSION 10
+#define PCRE2_CODE_UNIT_WIDTH 8
 
 #define MALLOC_LIBRARY "system"
 
